/**
 * Helper service for returning information extracted from repository image metadata.
 */
angular.module('quay').factory('ImageMetadataService', ['UtilService', function(UtilService) {
  var metadataService = {};
  metadataService.getFormattedCommand = function(image) {
    if (!image || !image.command || !image.command.length) {
      return '';
    }

    var getCommandStr = function(command) {
      // Handle /bin/sh commands specially.
      if (command.length > 2 && command[0] == '/bin/sh' && command[1] == '-c') {
        return command[2];
      }

      return command.join(' ');
    };

    return getCommandStr(image.command);
  };

  metadataService.getEscapedFormattedCommand = function(image) {
    return UtilService.textToSafeHtml(metadataService.getFormattedCommand(image));
  };

  metadataService.getImageCommand = function(image, imageId) {
    if (!image.__imageMap) {
      image.__imageMap = {};
      for (var i = 0; i < image.history.length; ++i) {
        var cimage = image.history[i];
        image.__imageMap[cimage.id] = cimage;
      }
    }

    return getDockerfileCommand(image.__imageMap[imageId].command);
  };

  var getDockerfileCommand = function(command) {
    if (!command) { return ''; }

    // ["/bin/sh", "-c", "#(nop) RUN foo"]
    var commandPrefix = '#(nop)';

    if (command.length != 3) { return  ''; }
    if (command[0] != '/bin/sh' || command[1] != '-c') { return ''; }

    var cmd = command[2];
    if (cmd.substring(0, commandPrefix.length) != commandPrefix) {
      return 'RUN ' + cmd;
    }

    return command[2].substr(commandPrefix.length + 1);
  };

  return metadataService;
}]);